@@ -863,9 +863,12 @@ wnck_pager_button_release (GtkWidget        *widget,
 	  space = wnck_workspace_get (i);
 
 	  if (space)
-	    wnck_window_move_to_workspace (pager->priv->drag_window,
-					   space);
-	  
+            {
+              wnck_window_move_to_workspace (pager->priv->drag_window,
+                                             space);
+              if (space == wnck_screen_get_active_workspace (pager->priv->screen))
+                wnck_window_activate (pager->priv->drag_window);
+            }	  
 	}
       
       wnck_pager_clear_drag (pager);
